@@ -125,7 +125,7 @@ class SSOAdminClient(BaseClient):
         self, *, InstanceArn: str, PermissionSetArn: str, ManagedPolicyArn: str
     ) -> Dict[str, Any]:
         """
-        Attaches an Amazon Web Services managed policy ARN to a permission set.
+        Attaches an AWS managed policy ARN to a permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.attach_managed_policy_to_permission_set)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#attach_managed_policy_to_permission_set)
@@ -158,8 +158,8 @@ class SSOAdminClient(BaseClient):
         PrincipalId: str
     ) -> CreateAccountAssignmentResponseTypeDef:
         """
-        Assigns access to a principal for a specified Amazon Web Services account using
-        a specified permission set.
+        Assigns access to a principal for a specified AWS account using a specified
+        permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.create_account_assignment)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#create_account_assignment)
@@ -172,8 +172,8 @@ class SSOAdminClient(BaseClient):
         InstanceAccessControlAttributeConfiguration: InstanceAccessControlAttributeConfigurationTypeDef
     ) -> Dict[str, Any]:
         """
-        Enables the attributes-based access control (ABAC) feature for the specified
-        Amazon Web Services SSO instance.
+        Enables the attributes-based access control (ABAC) feature for the specified IAM
+        Identity Center instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.create_instance_access_control_attribute_configuration)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#create_instance_access_control_attribute_configuration)
@@ -190,7 +190,7 @@ class SSOAdminClient(BaseClient):
         Tags: Sequence[TagTypeDef] = ...
     ) -> CreatePermissionSetResponseTypeDef:
         """
-        Creates a permission set within a specified Amazon Web Services SSO instance.
+        Creates a permission set within a specified IAM Identity Center instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.create_permission_set)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#create_permission_set)
@@ -207,8 +207,8 @@ class SSOAdminClient(BaseClient):
         PrincipalId: str
     ) -> DeleteAccountAssignmentResponseTypeDef:
         """
-        Deletes a principal's access from a specified Amazon Web Services account using
-        a specified permission set.
+        Deletes a principal's access from a specified AWS account using a specified
+        permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.delete_account_assignment)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#delete_account_assignment)
@@ -229,8 +229,8 @@ class SSOAdminClient(BaseClient):
     ) -> Dict[str, Any]:
         """
         Disables the attributes-based access control (ABAC) feature for the specified
-        Amazon Web Services SSO instance and deletes all of the attribute mappings that
-        have been configured.
+        IAM Identity Center instance and deletes all of the attribute mappings that have
+        been configured.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.delete_instance_access_control_attribute_configuration)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#delete_instance_access_control_attribute_configuration)
@@ -278,9 +278,9 @@ class SSOAdminClient(BaseClient):
         self, *, InstanceArn: str
     ) -> DescribeInstanceAccessControlAttributeConfigurationResponseTypeDef:
         """
-        Returns the list of Amazon Web Services SSO identity store attributes that have
-        been configured to work with attributes-based access control (ABAC) for the
-        specified Amazon Web Services SSO instance.
+        Returns the list of IAM Identity Center identity store attributes that have been
+        configured to work with attributes-based access control (ABAC) for the specified
+        IAM Identity Center instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.describe_instance_access_control_attribute_configuration)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#describe_instance_access_control_attribute_configuration)
@@ -325,8 +325,7 @@ class SSOAdminClient(BaseClient):
         self, *, InstanceArn: str, PermissionSetArn: str, ManagedPolicyArn: str
     ) -> Dict[str, Any]:
         """
-        Detaches the attached Amazon Web Services managed policy ARN from the specified
-        permission set.
+        Detaches the attached AWS managed policy ARN from the specified permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.detach_managed_policy_from_permission_set)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#detach_managed_policy_from_permission_set)
@@ -375,8 +374,8 @@ class SSOAdminClient(BaseClient):
         Filter: OperationStatusFilterTypeDef = ...
     ) -> ListAccountAssignmentCreationStatusResponseTypeDef:
         """
-        Lists the status of the Amazon Web Services account assignment creation requests
-        for a specified Amazon Web Services SSO instance.
+        Lists the status of the AWS account assignment creation requests for a specified
+        IAM Identity Center instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_creation_status)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_account_assignment_creation_status)
@@ -391,8 +390,8 @@ class SSOAdminClient(BaseClient):
         Filter: OperationStatusFilterTypeDef = ...
     ) -> ListAccountAssignmentDeletionStatusResponseTypeDef:
         """
-        Lists the status of the Amazon Web Services account assignment deletion requests
-        for a specified Amazon Web Services SSO instance.
+        Lists the status of the AWS account assignment deletion requests for a specified
+        IAM Identity Center instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_deletion_status)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_account_assignment_deletion_status)
@@ -408,8 +407,8 @@ class SSOAdminClient(BaseClient):
         NextToken: str = ...
     ) -> ListAccountAssignmentsResponseTypeDef:
         """
-        Lists the assignee of the specified Amazon Web Services account with the
-        specified permission set.
+        Lists the assignee of the specified AWS account with the specified permission
+        set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignments)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_account_assignments)
@@ -425,8 +424,7 @@ class SSOAdminClient(BaseClient):
         NextToken: str = ...
     ) -> ListAccountsForProvisionedPermissionSetResponseTypeDef:
         """
-        Lists all the Amazon Web Services accounts where the specified permission set is
-        provisioned.
+        Lists all the AWS accounts where the specified permission set is provisioned.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_accounts_for_provisioned_permission_set)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_accounts_for_provisioned_permission_set)
@@ -451,7 +449,7 @@ class SSOAdminClient(BaseClient):
         self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListInstancesResponseTypeDef:
         """
-        Lists the Amazon Web Services SSO instances that the caller has access to.
+        Lists the IAM Identity Center instances that the caller has access to.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_instances)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_instances)
@@ -466,8 +464,7 @@ class SSOAdminClient(BaseClient):
         NextToken: str = ...
     ) -> ListManagedPoliciesInPermissionSetResponseTypeDef:
         """
-        Lists the Amazon Web Services managed policy that is attached to a specified
-        permission set.
+        Lists the AWS managed policy that is attached to a specified permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_managed_policies_in_permission_set)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_managed_policies_in_permission_set)
@@ -482,8 +479,8 @@ class SSOAdminClient(BaseClient):
         Filter: OperationStatusFilterTypeDef = ...
     ) -> ListPermissionSetProvisioningStatusResponseTypeDef:
         """
-        Lists the status of the permission set provisioning requests for a specified
-        Amazon Web Services SSO instance.
+        Lists the status of the permission set provisioning requests for a specified IAM
+        Identity Center instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_set_provisioning_status)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_permission_set_provisioning_status)
@@ -493,7 +490,7 @@ class SSOAdminClient(BaseClient):
         self, *, InstanceArn: str, NextToken: str = ..., MaxResults: int = ...
     ) -> ListPermissionSetsResponseTypeDef:
         """
-        Lists the  PermissionSet s in an Amazon Web Services SSO instance.
+        Lists the  PermissionSet s in an IAM Identity Center instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_permission_sets)
@@ -509,8 +506,7 @@ class SSOAdminClient(BaseClient):
         NextToken: str = ...
     ) -> ListPermissionSetsProvisionedToAccountResponseTypeDef:
         """
-        Lists all the permission sets that are provisioned to a specified Amazon Web
-        Services account.
+        Lists all the permission sets that are provisioned to a specified AWS account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets_provisioned_to_account)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_permission_sets_provisioned_to_account)
@@ -560,8 +556,8 @@ class SSOAdminClient(BaseClient):
         PermissionsBoundary: PermissionsBoundaryTypeDef
     ) -> Dict[str, Any]:
         """
-        Attaches an Amazon Web Services managed or customer managed policy to the
-        specified  PermissionSet as a permissions boundary.
+        Attaches an AWS managed or customer managed policy to the specified
+        PermissionSet as a permissions boundary.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.put_permissions_boundary_to_permission_set)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#put_permissions_boundary_to_permission_set)
@@ -594,9 +590,8 @@ class SSOAdminClient(BaseClient):
         InstanceAccessControlAttributeConfiguration: InstanceAccessControlAttributeConfigurationTypeDef
     ) -> Dict[str, Any]:
         """
-        Updates the Amazon Web Services SSO identity store attributes that you can use
-        with the Amazon Web Services SSO instance for attributes-based access control
-        (ABAC).
+        Updates the IAM Identity Center identity store attributes that you can use with
+        the IAM Identity Center instance for attributes-based access control (ABAC).
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.update_instance_access_control_attribute_configuration)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#update_instance_access_control_attribute_configuration)
